prettyqt package
================

Subpackages
-----------

.. toctree::

    prettyqt.core
    prettyqt.widgets

Module contents
---------------

.. automodule:: prettyqt
    :members:
    :undoc-members:
    :show-inheritance:
